"""Top-level package for geemap."""

__author__ = """Qiusheng Wu"""
__email__ = 'giswqs@gmail.com'
__version__ = '0.6.7'

from .geemap import *
from .basemaps import ee_basemaps
from .legends import builtin_legends